/***************************************************************************
 *   Copyright (C) 2004 by Gerd Fleischer                                  *
 *   gerdfleischer@web.de                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KLINPOPUP_H_
#define _KLINPOPUP_H_

#define POPUP_DIR "/var/lib/klinpopup"
#define ID_STATUS_TEXT 10
#define NEW_ICON 0
#define NORMAL_ICON 1
#define MS_NOTHING 0
#define MS_SOUND_TRAY 1
#define MS_ACTIVATE 2
#define MS_ALL 3

#include <libsmbclient.h>

#include <qtimer.h>
#include <qstring.h>
#include <qptrlist.h>

#include <kuniqueapplication.h>
#include <kmainwindow.h>
#include <kaction.h>
#include <kconfig.h>
#include <kkeydialog.h>

#include "popupmessage.h"
#include "klinpopupview.h"
#include "systemtray.h"

class KToggleAction;
class SystemTray;

/**
 * This class serves as the main window for KLinPopup.  It handles the
 * menus, toolbars, and status bars.
 *
 * @short Main window class
 * @author Gerd Fleischer <gerdfleischer@web.de>
 * @version 0.3
 */
class KLinPopup : public KMainWindow
{
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    KLinPopup();

    //Default Destructor

    void auth_smbc_get_data(const char *server,const char *share,
                            char *workgroup, int wgmaxlen,
                            char *username, int unmaxlen,
                            char *password, int pwmaxlen);

public slots:
    void newPopup();

protected:
    void hideEvent(QHideEvent *) { hide(); }
//    void closeEvent(QCloseEvent *);
    void focusInEvent(QFocusEvent *);

private slots:
    void slotQuit();
    void popupFileTimerDone();
    void signalNewMessage(const QString &, const QString &, const QString &, const QString &, const QString &);
    void replyPopup();
    void firstPopup() {  messageList.first(); showPopup(); popupHelper(); }
    void prevPopup() { messageList.prev(); showPopup(); popupHelper(); }
    void nextPopup() { messageList.next(); showPopup(); popupHelper(); }
    void lastPopup() { messageList.last(); showPopup(); popupHelper(); }
    void unreadPopup();
    void deletePopup() { messageList.remove(); showPopup(); popupHelper(); }
    void optionsShowMenubar();
    void optionsShowToolbar();
    void optionsShowStatusbar();
    void optionsConfigureKeys() { KKeyDialog::configure(actionCollection()); }
    void optionsConfigureToolbars();
    void optionsPreferences();
    void newToolbarConfig();
    void changeStatusbar(const QString &);
    void changeCaption(const QString &text) { setCaption(text); }
    void settingsChanged();
    void deleteMakePopupView(QWidget *qw) { delete qw; }

private:
    virtual bool queryClose();
    void setupAccel();
    void setupActions();
    void initSystemTray();
    void initBars();
    void initTimer();
    bool checkPopupFileDirectory();
    void checkSmbclientBin();
    void checkMessageMap();
    void showPopup();
    void createStatText();
    void updateStats();
    QString createSenderText();
    void readConfig();
    void popupHelper();

    KLinPopupView *m_view;

    //config and actions
    KConfig *cfg;
    SystemTray *m_systemTray;
    KToggleAction *m_menubarAction;
    KToggleAction *m_toolbarAction;
    KToggleAction *m_statusbarAction;
    KAction *newPopupAction;
    KAction *replyPopupAction;
    KAction *firstPopupAction;
    KAction *prevPopupAction;
    KAction *nextPopupAction;
    KAction *lastPopupAction;
    KAction *unreadPopupAction;
    KAction *deletePopupAction;

    int unreadMessages;
    QTimer *popupFileTimer;
    QString messageText;
    QString popupFileDirectory;
    QString captionText;
    QString statText;
    QPtrList<popupMessage> messageList;

    //option variables
    bool optRunDocked;
    int optTimerInterval;
    bool optDisplaySender;
    bool optDisplayMachine;
    bool optDisplayIP;
    int optTimeFormat;
    int optNewMessageSignaling;
    QString optNewPopupSound;
    QString optSmbclientBin;
    int optEncoding;
};

extern KLinPopup* p_klinpopup;

extern "C"
{

void auth_smbc_get_data(const char *server,const char *share,
                        char *workgroup, int wgmaxlen,
                        char *username, int unmaxlen,
                        char *password, int pwmaxlen);

//SMBCSRV * smbc_get_cached_server(SMBCCTX * context, const char * server,
//                  const char * share, const char * workgroup, const char * user);

}

#endif // _KLINPOPUP_H_

